==> snippet_manager-8.x-1.0-rc4.tar.gz: snippet_manager/src/Plugin/SnippetVariable/File.php <==
<?php

namespace Drupal\snippet_manager\Plugin\SnippetVariable;

use Drupal\Core\Form\FormStateInterface;
use Drupal\snippet_manager\SnippetVariableBase;
use Drupal\snippet_manager\SnippetVariableInterface;

/**
 * Provides file variable type.
 *
 * This plugin is serialized on ajax form submit, so that we cannot save
 * dependency as class properties.
 *
 * @SnippetVariable(
 *   id = "file",
 *   title = @Translation("File"),
 *   category = @Translation("Other"),
 * )
 */
class File extends SnippetVariableBase implements SnippetVariableInterface {

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {

    // TODO: Validate file extensions.
    $form['file'] = [
      '#title' => 'File',
      '#type' => 'managed_file',
      '#upload_location' => 'public://snippet',
      '#required' => TRUE,
    ];

    if ($this->configuration['file']) {
      $file = \Drupal::service('entity.repository')->loadEntityByUuid('file', $this->configuration['file']);
      if ($file) {
        $form['file']['#default_value'] = [$file->id()];
      }
    }

    $form['format'] = [
      '#title' => t('Format'),
      '#type' => 'radios',
      '#options' => [
        'generic' => t('Generic'),
        'url' => t('URL'),
      ],
      '#default_value' => $this->configuration['format'],
      '#required' => TRUE,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {

    $values = $form_state->getValues();
    if (isset($values['file'][0])) {
      $file = \Drupal::entityTypeManager()->getStorage('file')->load($values['file'][0]);
      $this->configuration['file'] = $file ? $file->uuid() : NULL;
    }

    $this->configuration['format'] = $values['format'];
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'file' => NULL,
      'format' => 'generic',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getContent() {

    $build = [];

    if ($this->configuration['file']) {
      /** @var \Drupal\file\FileInterface $file */
      $file = \Drupal::service('entity.repository')->loadEntityByUuid('file', $this->configuration['file']);
      if ($file) {
        if ($this->configuration['format'] == 'generic') {
          $build['file'] = [
            '#theme' => 'file_link',
            '#file' => $file,
          ];
        }
        else {
          $build['file'] = [
            '#markup' => file_create_url($file->getFileUri()),
          ];
        }
        $build['file']['#cache']['tags'] = $file->getCacheTags();

      }
    }

    return $build;
  }

}

==> snippet_manager-8.x-1.2.tar.gz: snippet_manager/src/Plugin/SnippetVariable/File.php <==
<?php

namespace Drupal\snippet_manager\Plugin\SnippetVariable;

use Drupal\Core\Form\FormStateInterface;
use Drupal\snippet_manager\SnippetVariableBase;

/**
 * Provides file variable type.
 *
 * This plugin is serialized on ajax form submit, so that we cannot save
 * dependency as class properties.
 *
 * @SnippetVariable(
 *   id = "file",
 *   title = @Translation("File"),
 *   category = @Translation("Other"),
 * )
 */
class File extends SnippetVariableBase {

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {

    // This form is intended for snippet administrators who by definition are
    // trusted. So that no need to limit the list of allowed file extensions.
    // Unfortunatly at the time being it is not possible to allow uploading
    // files with any file extension so we just expand the list to allow most
    // needed file types.
    // @see https://www.drupal.org/project/drupal/issues/997900
    $allowed_extensions = 'jpg jpeg gif png apng webp mov avi mp3 mp4 svg svgz woff woff2 txt doc docx xls xlsx pdf ppt pps odt ods odp rar zip gz tgz';

    $form['file'] = [
      '#title' => 'File',
      '#type' => 'managed_file',
      '#upload_location' => 'public://snippet',
      '#required' => TRUE,
      '#upload_validators'  => [
        'file_validate_extensions' => [$allowed_extensions],
      ],
      '#description' => $this->t('Allowed types: @extensions.', ['@extensions' => $allowed_extensions]),
    ];

    if ($this->configuration['file']) {
      /* @var \Drupal\file\FileInterface $file */
      $file = \Drupal::service('entity.repository')->loadEntityByUuid('file', $this->configuration['file']);
      if ($file) {
        $form['file']['#default_value'] = [$file->id()];
      }
    }

    $form['format'] = [
      '#title' => $this->t('Format'),
      '#type' => 'radios',
      '#options' => [
        'generic' => $this->t('Generic'),
        'url' => $this->t('URL'),
      ],
      '#default_value' => $this->configuration['format'],
      '#required' => TRUE,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {

    $values = $form_state->getValues();
    if (isset($values['file'][0])) {
      /* @var \Drupal\file\FileInterface $file */
      $file = \Drupal::entityTypeManager()->getStorage('file')->load($values['file'][0]);
      $this->configuration['file'] = $file ? $file->uuid() : NULL;
    }

    $this->configuration['format'] = $values['format'];
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'file' => NULL,
      'format' => 'generic',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function build() {

    $build = [];

    if ($this->configuration['file']) {
      /** @var \Drupal\file\FileInterface $file */
      $file = \Drupal::service('entity.repository')->loadEntityByUuid('file', $this->configuration['file']);
      if ($file) {
        if ($this->configuration['format'] == 'generic') {
          $build['file'] = [
            '#theme' => 'file_link',
            '#file' => $file,
          ];
        }
        else {
          $build['file'] = [
            '#markup' => file_create_url($file->getFileUri()),
          ];
        }
        $build['file']['#cache']['tags'] = $file->getCacheTags();

      }
    }

    return $build;
  }

}
